@@ -8,7 +8,7 @@ use warnings;
 
 use Import::Into;
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 sub import {
     my $class  = shift;
@@ -42,24 +42,30 @@ sub extort::into {
             next;
         }
 
+        my $subname;
+        if ($argument and $argument =~ /=/) {
+            ($argument, $subname) = split /=/, $argument;
+        }
+
         $seen{$namespace}++
             || eval "require $namespace";
 
-        if ($argument =~ /\W/) {
+        if (!$subname and $argument =~ /\W/) {
             $namespace->import::into($target, $argument);
             next;
         }
 
         no strict 'refs';
         my %EXPORT_TAGS = %{"${namespace}::EXPORT_TAGS"};
-        if ($EXPORT_TAGS{$argument}) {
+        if (!$subname and $EXPORT_TAGS{$argument}) {
             $namespace->import::into($target, $argument);
             next;
         }
 
         if ($namespace->can($argument)) {
             no warnings 'redefine';
-            *{"${target}::${argument}"} = \&{"${namespace}::${argument}"};
+            $subname //= $argument;
+            *{"${target}::${subname}"} = \&{"${namespace}::${argument}"};
             next;
         }
 
@@ -84,7 +90,7 @@ Extorter - Import Routines By Any Means Necessary
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -146,7 +152,7 @@ your program and any C<redefine> warnings will be suppressed. This is a feature
 not a bug. B<NOTE: Any declaration prefixed with an asterisk is assumed to be a
 fully-qualified namespace of a package and is imported directly.>
 
-=head1 VERSIONS AND FEATURES
+=head1 FEATURES AND VERSIONS
 
 Declaring version requirements and version-specific features is handled a bit
 differently. As mentioned in the description, any declaration prefixed with an
@@ -180,6 +186,7 @@ exporter which implements the Exporter interface. The following is an example:
 
     our @EXPORT_OK = qw(
         optional_thing1
+        optional_thing2
     );
 
     our @IMPORT_OK = qw(
@@ -191,6 +198,10 @@ exporter which implements the Exporter interface. The following is an example:
         # does stuff
     }
 
+    sub optional_thing2 {
+        # does stuff
+    }
+
     sub import {
         my ($class, $target) = (shift, caller);
         $class->extort::into($target, $_) for @IMPORT_OK;
@@ -288,6 +299,15 @@ example:
     $package->extort::into($target, @scalar_utils);
     $package->extort::into($target, @list_utils);
 
+It is also possible to copy a routine from one namespace and install it into a
+different namespace using a different name. The following is an example of that:
+
+    $package->extort::into($target, 'Getopt::Long::GetOptions=options');
+
+Given the example, the C<$target> namespace now contains a code reference named
+C<options> which references the subroutine C<GetOptions> as defined in the
+L<Getopt::Long> package.
+
 =head1 AUTHOR
 
 Al Newkirk <anewkirk@ana.io>
